<?php
/**
 * Dynamic CSS for the frontend.
 *
 * @package Fitness
 */

defined( 'WPINC' ) || exit;

/**
 * Helper function.
 * Merge and combine the CSS elements.
 *
 * @param  string|array $elements An array of our elements.
 *                                If we use a string then it is directly returned.
 * @return string
 */
function fitness_implode( $elements = array() ) {

	if ( ! is_array( $elements ) ) {
		return $elements;
	}

	// Make sure our values are unique.
	$elements = array_unique( $elements );

	// Sort elements alphabetically.
	// This way all duplicate items will be merged in the final CSS array.
	sort( $elements );

	// Implode items and return the value.
	return implode( ',', $elements );

}

/**
 * Maps elements from dynamic css to the selector.
 *
 * @param  array  $elements The elements.
 * @param  string $selector The selector.
 * @return array
 */
function fitness_map_selector( $elements, $selector ) {
	$array = array();

	foreach ( $elements as $element ) {
		$array[] = $element . $selector;
	}

	return $array;
}

/**
 * Map CSS selectors from values.
 *
 * @param array $css    Array of dynamic CSS.
 * @param array $values Array of values.
 */
function fitness_map_css_selectors( &$css, $values ) {
	if ( isset( $values['css-selectors'] ) ) {
		$elements = $values['css-selectors'];
		unset( $values['css-selectors'] );

		$css[ $elements ] = $values;
	}
}

/**
 * Merge CSS values.
 *
 * @param array $css    Array of dynamic CSS.
 * @param array $values Array of values.
 */
function fitness_merge_value( &$css, $values ) {
	foreach ( (array) $values as $id => $val ) {
		$css[ $id ] = $val;
	}
}

/**
 * Format of the $css array:
 * $css['media-query']['element']['property'] = value
 *
 * If no media query is required then set it to 'global'
 *
 * If we want to add multiple values for the same property then we have to make it an array like this:
 * $css[media-query][element]['property'][] = value1
 * $css[media-query][element]['property'][] = value2
 *
 * Multiple values defined as an array above will be parsed separately.
 */
function fitness_dynamic_css_array() {

	global $wp_version;

	$css       = array();
	$c_page_id = fitness()->get_page_id();

	// Site Background.
	$css['global']['html body'] = Fitness_Sanitize::background( fitness_get_settings( 'mts_background' ) );

	// Nav Background.
	$css['global']['#header, #header.sticky-navigation.sticky-navigation-active'] = Fitness_Sanitize::background( fitness_get_settings( 'header_background' ) );
	// Home Nav Background
	$css['global']['header.home-header #header, header.home-header #header.sticky-navigation.sticky-navigation-active'] = Fitness_Sanitize::background( fitness_get_settings( 'home_header_background' ) );

	// Content Font.
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'content_font' ) ) );
	// Home Logo Font.
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'fitness_home_logo' ) ) );
	// Logo Font.
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'fitness_logo' ) ) );
	// Home Primary Navigation font.
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'home_secondary_navigation_font' ) ) );
	// Primary Navigation font.
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'secondary_navigation_font' ) ) );
	// Homepage post title font.
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'home_title_font' ) ) );
	// Pagination.
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'pagination_font' ) ) );
	// single heading font.
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'single_heading_font' ) ) );
	// Breadcrumbs font.
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'breadcrumb_font' ) ) );
	// Single post title font.
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'single_title_font' ) ) );
	// Single Page titles font.
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'single_page_titles_font' ) ) );
	// Related Posts Section title font.
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'related_post_title_font' ) ) );
	// Single subscribe box.
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'single_subscribe_title_font' ) ) );
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'single_subscribe_text_font' ) ) );
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'single_subscribe_input_font' ) ) );
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'single_subscribe_submit_font' ) ) );
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'single_subscribe_small_text_font' ) ) );
	// Author Box.
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'single_authorbox_title_font' ) ) );
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'single_authorbox_author_name_font' ) ) );
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'single_authorbox_text_font' ) ) );
	// Footer Nav.
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'footer_nav_font' ) ) );
	// Sidebar widget title font.
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'sidebar_title_font' ) ) );
	// Sidebar widget font.
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'sidebar_url' ) ) );
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'sidebar_font' ) ) );
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'sidebar_post_title' ) ) );
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'sidebar_postinfo_font' ) ) );
	// Footer widget title font.
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'footer_fitness_logo' ) ) );
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'top_footer_title_font' ) ) );
	// Footer link font.
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'top_footer_link_font' ) ) );
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'top_footer_post_title' ) ) );
	// Footer widget font.
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'top_footer_font' ) ) );
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'top_footer_meta_font' ) ) );
	// Copyrights section font.
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'copyrights_font' ) ) );
	// H1 title in the content.
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'h1_headline' ) ) );
	// H2 title in the content.
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'h2_headline' ) ) );
	// H3 title in the content.
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'h3_headline' ) ) );
	// H4 title in the content.
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'h4_headline' ) ) );
	// H5 title in the content.
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'h5_headline' ) ) );
	// H6 title in the content.
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'h6_headline' ) ) );

	// Footer background.
	$css['global']['#site-footer'] = Fitness_Sanitize::background( fitness_get_settings( 'mts_footer_background' ) );
	// Copyrights background.
	$css['global']['.copyrights'] = Fitness_Sanitize::background( fitness_get_settings( 'mts_copyrights_background' ) );
	//Blog Carousel
	$css['global']['.blog-carousel-section'] = Fitness_Sanitize::background( fitness_get_settings( 'carousel_background' ) );
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'carousel_heading_font' ) ) );
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'carousel_category_font' ) ) );
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'carousel_title_font' ) ) );
	fitness_merge_value( $css['global']['.blog-carousel-section'], Fitness_Sanitize::padding( fitness_get_settings( 'carousel_padding' ) ) );
	fitness_merge_value( $css['global']['.blog-carousel-section'], Fitness_Sanitize::margin( fitness_get_settings( 'carousel_margin' ) ) );
	//Archive settings
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'archive_post_date_font' ) ) );
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'archive_meta_info_font' ) ) );
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'archive_post_title_font' ) ) );
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'archive_post_excerpt_font' ) ) );
	$css['global']['.archive-posts.layout-default .post-info > span']['background-color'] = Fitness_Sanitize::color( fitness_get_settings( 'archive_meta_info_bg' ) );

	fitness_dynamic_css_skin( $css );
	fitness_sidebar_position( $css );
	fitness_header( $css );
	fitness_sidebar_styling( $css );
	fitness_home_sections( $css );
	fitness_post_layouts( $css );
	fitness_post_pagination( $css );
	fitness_footer( $css );
	fitness_copyrights( $css );
	fitness_single( $css );
	fitness_single_social_buttons( $css );
	fitness_misc_css( $css );

	return apply_filters( 'fitness_dynamic_css_array', $css );
}

/**
 * Skin CSS
 *
 * @param array $css Array of dynamic CSS.
 */
function fitness_dynamic_css_skin( &$css ) {

	// Primary Color.
	$primary_color_scheme = Fitness_Sanitize::color( fitness_get_settings( 'primary_color_scheme' ) );

	$dark_color = color_luminance( $primary_color_scheme, -0.3 );

	// Text Color.
	$elements = array(
		'a',
		'body a:hover',
		'.breadcrumb a',
		'.rank-math-breadcrumb a',
		'.single_post .thecontent a',
		'.reply a',
		'.reply i',
		'.featured-content a.title:hover',
		'.latestPost .title a:hover',
		'.related-posts .title a:hover',
		'.layout-default .latestPost .title a:hover',
		'.woocommerce ul.products li.product .price',
		'.product_list_widget .amount',
		'.woocommerce div.product p.price, .woocommerce div.product span.price',
		'.shareit-circular.standard .fa:hover',
		'.textwidget a',
		'#wp-calendar td#today',
		'.pnavigation2 a',
		'footer .widget li a:hover',
		'#sidebar .widget li a:hover',
		'.title a:hover',
		'#tabber .inside li a:hover',
		'.fn a',
		'.related-posts .title a:hover',
		'.layout-subscribe .widget #wp-subscribe .title span',
		'.footer-nav li a:hover',
		'blockquote:after',
		'article ul li::before',
		'#secondary-navigation li:hover',
		'blockquote::before',
		'.button.border:hover',
		' #copyright-note a',
		'.widget .sbutton',
		'.error404 .sbutton',
		'.search .sbutton',
		'.post-info a i',
		'#secondary-navigation .navigation ul ul a:hover',
		'.home-header #secondary-navigation li:hover > a',
		'.main-header:not(.home-header) .menu-item-has-children>a:after',
		'#secondary-navigation li:hover > a',
		'#site-header .header-search .searchbox-open .searchbox-icon',
		'.header-default .header-search span.sbutton',
		'.service-item a:hover h3',
		'.twogrid-section h3 a:hover',
		'#site-footer .post-title a:hover',
		'#site-footer .entry-title a:hover',
		'.sidebar .widget a:hover',
		'.sidebar .post-title a:hover',
		'.sidebar .entry-title a:hover',
	);

	$css['global'][ fitness_implode( $elements ) ]['color'] = $primary_color_scheme;
	$css['global']['#sidebar .widget a:hover']['color']     = $primary_color_scheme;

	// Text Color Important.
	$elements = array(
		'.layout-featured .latestPost .title a:hover',
		'.widget .review_thumb_large .review-result',
		'.widget .review_thumb_large .review-total-only.large-thumb',
		'footer .widget .wpt_widget_content .tab_title.selected a',
		'footer .widget .wp_review_tab_widget_content .tab_title.selected a',
	);
	$css['global'][ fitness_implode( $elements ) ]['color'] = $primary_color_scheme . '!important';

	// Background Color.
	$elements = array(
		'.pace .pace-progress',
		'#mobile-menu-wrapper ul li a:hover',
		'#commentform input#submit',
		'#mtscontact_submit',
		'.navigation #wpmm-megamenu .wpmm-pagination a',
		'.wpmm-megamenu-showing.wpmm-light-scheme',
		'.mts-subscribe input[type="submit"]',
		'.widget_product_search button[type="submit"]',
		'#move-to-top:hover',
		'#tabber ul.tabs li a.selected',
		'.navigation ul .sfHover a',
		'.widget-slider .slide-caption',
		'.owl-prev:hover, .owl-next:hover',
		'.widget .wp-subscribe-wrap h4.title span.decor:after',
		'.woocommerce a.button',
		'.woocommerce-page a.button',
		'.woocommerce button.button',
		'.woocommerce-page button.button',
		'.woocommerce input.button',
		'.woocommerce-page input.button',
		'.woocommerce #respond input#submit',
		'.woocommerce-page #respond input#submit',
		'.woocommerce #content input.button',
		'.woocommerce-page #content input.button',
		'.woocommerce .bypostauthor:after',
		'.woocommerce nav.woocommerce-pagination ul li span.current',
		'.woocommerce-page nav.woocommerce-pagination ul li span.current',
		'.woocommerce #content nav.woocommerce-pagination ul li span.current',
		'.woocommerce-page #content nav.woocommerce-pagination ul li span.current',
		'.woocommerce nav.woocommerce-pagination ul li a:hover',
		'.woocommerce-page nav.woocommerce-pagination ul li a:hover',
		'.woocommerce #content nav.woocommerce-pagination ul li a:hover',
		'.woocommerce-page #content nav.woocommerce-pagination ul li a:hover',
		'.woocommerce nav.woocommerce-pagination ul li a:focus',
		'.woocommerce-page nav.woocommerce-pagination ul li a:focus',
		'.woocommerce #content nav.woocommerce-pagination ul li a:focus',
		'.woocommerce-page #content nav.woocommerce-pagination ul li a:focus',
		'.woocommerce a.button',
		'.woocommerce-page a.button',
		'.woocommerce button.button',
		'.woocommerce-page button.button',
		'.woocommerce input.button',
		'.woocommerce-page input.button',
		'.woocommerce #respond input#submit',
		'.woocommerce-page #respond input#submit',
		'.woocommerce #content input.button',
		'.woocommerce-page #content input.button',
		'.woocommerce #respond input#submit.alt.disabled',
		'.woocommerce #respond input#submit.alt.disabled:hover',
		'.woocommerce #respond input#submit.alt:disabled',
		'.woocommerce #respond input#submit.alt:disabled:hover',
		'.woocommerce #respond input#submit.alt:disabled[disabled]',
		'.woocommerce #respond input#submit.alt:disabled[disabled]:hover',
		'.woocommerce a.button.alt.disabled, .woocommerce a.button.alt.disabled:hover',
		'.woocommerce a.button.alt:disabled',
		'.woocommerce a.button.alt:disabled:hover',
		'.woocommerce a.button.alt:disabled[disabled]',
		'.woocommerce a.button.alt:disabled[disabled]:hover',
		'.woocommerce button.button.alt.disabled',
		'.woocommerce button.button.alt.disabled:hover',
		'.woocommerce button.button.alt:disabled',
		'.woocommerce button.button.alt:disabled:hover',
		'.woocommerce button.button.alt:disabled[disabled]',
		'.woocommerce button.button.alt:disabled[disabled]:hover',
		'.woocommerce input.button.alt.disabled',
		'.woocommerce input.button.alt.disabled:hover',
		'.woocommerce input.button.alt:disabled',
		'.woocommerce input.button.alt:disabled:hover',
		'.woocommerce input.button.alt:disabled[disabled]',
		'.woocommerce input.button.alt:disabled[disabled]:hover',
		'#wpmm-megamenu .review-total-only',
		'#searchsubmit',
		'#add_payment_method .wc-proceed-to-checkout a.checkout-button',
		'.woocommerce-cart .wc-proceed-to-checkout a.checkout-button',
		'.woocommerce-checkout .wc-proceed-to-checkout a.checkout-button',
		'.woocommerce #respond input#submit.alt',
		'.woocommerce a.button.alt',
		'.woocommerce button.button.alt',
		'.woocommerce input.button.alt',
		'.woocommerce-account .woocommerce-MyAccount-navigation li.is-active',
		'.widget #wp-subscribe form::after',
		'.button',
		'.instagram-button a',
		'.woocommerce .woocommerce-widget-layered-nav-dropdown__submit',
		'.layout-subscribe form:after',
		'.f-widget .widget #wp-subscribe form:after',
		'.owl-prev:hover, .owl-next:hover',
		'.woocommerce .widget_price_filter .ui-slider .ui-slider-handle',
		'.woocommerce .widget_price_filter .ui-slider .ui-slider-range',
		'.latestPost-review-wrapper',
		'.latestPost .review-type-circle.latestPost-review-wrapper',
		'.woocommerce span.onsale',
		'.widget .widget_wp_review_tab .review-total-only.large-thumb',
		'#sidebar .widget h3::before',
		'#sidebar .widget #wp-subscribe .title::before',
		'.f-widget .widget #wp-subscribe input.submit',
		'.owl-controls .owl-dot.active span',
		'.shareit-circular .social-icon',
		'.author-social a',
		'.aboutme-social a',
		'.widget #wp-subscribe input.submit',
		'.blog-carousel .owl-dots',
		'.home-header #header.sticky-navigation.sticky-navigation-active',
	);

	$css['global'][ fitness_implode( $elements ) ]['background-color'] = $primary_color_scheme;

	// Background Color Important.
	$elements = array(
		'.tagcloud a:hover, #sidebar .widget .tagcloud a:hover',
		'.widget .wpt_widget_content #tags-tab-content ul li a:hover ',
	);
	$css['global'][ fitness_implode( $elements ) ]['background-color'] = $primary_color_scheme . '!important';

	// Border Color.
	$elements = array(
		'.flex-control-thumbs .flex-active',
		'#wrapper .cooked-recipe-ingredients .cooked-ingredient-checkbox',
		'blockquote',
		'.commentmetadata',
		'.layout-default .latestPost .post-date .date-circle',
	);

	$css['global'][ fitness_implode( $elements ) ]['border-color'] = $primary_color_scheme;

	// Border Color.
	$elements = array(
		'#sidebar .widget .wpt_widget_content .tab_title.selected a',
		'#sidebar .widget .wp_review_tab_widget_content .tab_title.selected a',
	);

	$css['global'][ fitness_implode( $elements ) ]['border-color'] = $primary_color_scheme . '!important';

	// Dark Colors.
	// Dark Background Color.
	$elements = array(
		'.blog-carousel .owl-controls .owl-dot span',
	);

	$css['global'][ fitness_implode( $elements ) ]['background-color'] = $dark_color;
	$css['global'][ fitness_implode( $elements ) ]['border-color']     = $dark_color;

}

/**
 * Sidebar Position
 *
 * @param array $css Array of dynamic CSS.
 */
function fitness_sidebar_position( &$css ) {

	// Sidebar position.
	$sidebar_position = fitness_get_settings( 'mts_layout' );

	$sidebar_metabox_location = '';
	if ( is_page() || is_single() ) {
		$sidebar_metabox_location = get_post_meta( get_the_ID(), '_mts_sidebar_location', true );
	}

	if ( 'right' !== $sidebar_metabox_location && ( 'sclayout' === $sidebar_position || 'left' === $sidebar_metabox_location ) ) {

		$css['global']['.article']['float']        = 'right';
		$css['global']['.sidebar.c-4-12']['float'] = 'left';

		if ( ! empty( fitness_get_settings( 'mts_social_buttons_floating' ) ) ) {
			$css['global']['.social-share-float .shareit-floating']['right']        = '50%';
			$css['global']['.social-share-float .shareit-floating']['margin-right'] = '-585px';
			//content padding
			$css['global']['#wrapper.social-share-float .article']['padding-left']  = '0px';
			$css['global']['#wrapper.social-share-float .article']['padding-right'] = '70px';

			$css['global']['article .sclayout .alignfull']['margin-right'] = 'calc(50% / .75 - 50vw)';

			$css['@media screen and (max-width: 1200px)']['.shareit-floating']['right'] = '0px';
			//margin-right
			$css['@media screen and (max-width: 1200px)']['.shareit-floating']['margin-right'] = '0px';
			//content
			$css['@media screen and (max-width: 1200px)']['#wrapper.social-share-float .article']['padding-right'] = '0px';
		}
	}

	//Gutenberg code
	if ( ! empty( fitness_get_settings( 'mts_social_buttons_floating' ) ) ) {
		//hide on mobile menu
		$css['@media screen and (max-width: 1200px)']['.article .shareit.top']['display']    = 'none';
		$css['@media screen and (max-width: 1200px)']['.article .shareit.bottom']['display'] = 'none';
		if ( 'left' !== $sidebar_metabox_location && ( 'cslayout' === $sidebar_position || 'right' === $sidebar_metabox_location ) ) {
			$css['global']['article .cslayout .alignfull']['margin-left'] = 'calc(50% / .75 - 50vw)';
		}
		if ( 'mts_nosidebar' == mts_custom_sidebar() ) {
			$css['global']['article .alignfull']['margin-left']            = 'calc(50% - 53vw)';
			$css['global']['article .alignfull']['max-width']              = '103vw';
			$css['global']['article .nosidebar .alignwide']['margin-left'] = '-7%';
			$css['global']['article .nosidebar .alignwide']['width']       = 'calc(100% + 9%)';
		}
	}

}

/**
 * Header
 *
 * @param array $css Array of dynamic CSS.
 */
function fitness_header( &$css ) {

	// Header.
	$header_class = array(
		'#header',
	);
	fitness_merge_value( $css['global'][ fitness_implode( $header_class ) ], Fitness_Sanitize::margin( fitness_get_settings( 'header_margin' ) ) );
	fitness_merge_value( $css['global'][ fitness_implode( $header_class ) ], Fitness_Sanitize::padding( fitness_get_settings( 'header_padding' ) ) );
	fitness_merge_value( $css['global']['.home-header #header'], Fitness_Sanitize::padding( fitness_get_settings( 'home_header_padding' ) ) );
	// Header Border.
	$header_border = Fitness_Sanitize::border( fitness_get_settings( 'mts_header_border' ) );
	$css['global'][ fitness_implode( $header_class ) ][ $header_border['direction'] ] = $header_border ['value'];

	// Homepage Header Position.
	$slider  = fitness_get_settings( 'home_slider' );
	$options = fitness_get_settings( 'homepage_layout' );

	if ( is_page_template( 'page-home.php' ) && ! empty( $slider ) && is_array( $slider ) && ( 'Slider' == $options['enabled']['slider'] ) ) {
		$css['global']['.home-header']['position'] = 'absolute';
	}

	// Main Nav.
	$main_nav_classes = array(
		'#secondary-navigation .navigation ul ul a',
		'#secondary-navigation .navigation ul ul a:link',
		'#secondary-navigation .navigation ul ul a:visited',
	);
	$css['global'][ fitness_implode( $main_nav_classes ) ]['color']            = Fitness_Sanitize::color( fitness_get_settings( 'main_navigation_dropdown_color' ) );
	$css['global']['#secondary-navigation .navigation ul ul a:hover']['color'] = Fitness_Sanitize::color( fitness_get_settings( 'main_navigation_dropdown_hover_color' ) );

	// Single color.
	$css['global']['.single_post .post-single-content a']['color'] = Fitness_Sanitize::color( fitness_get_settings( 'main_navigation_dropdown_hover_color' ) );

	// Contact info.
	if ( ! empty( fitness_get_settings( 'contact_info' ) ) && is_array( fitness_get_settings( 'contact_info' ) ) ) :

		$i            = 0;
		$contect_info = fitness_get_settings( 'contact_info' );

		foreach ( $contect_info as $info ) :

			++$i;

			$css['global'][ '.info-' . $i . ' .contact-info-icon' ]['color'] = Fitness_Sanitize::color( $info['contact_info_icon_color'] );

			$css['global'][ '.info-' . $i . ' p.small-text' ]['color'] = Fitness_Sanitize::color( $info['contact_info_small_text_color'] );

			$css['global'][ '.info-' . $i . ' p.large-text' ]['color'] = Fitness_Sanitize::color( $info['contact_info_text_color'] );

			$contect_info_border = Fitness_Sanitize::border( $info['contact_info_border'] );
			$css['global'][ '.info-' . $i ][ $contect_info_border['direction'] ] = $contect_info_border ['value'];

			fitness_merge_value( $css['global'][ '.info-' . $i ], Fitness_Sanitize::margin( $info['contact_info_margin'] ) );
			fitness_merge_value( $css['global'][ '.info-' . $i ], Fitness_Sanitize::padding( $info['contact_info_padding'] ) );

		endforeach;

	endif;

	// Header Ad.
	fitness_merge_value( $css['global']['.widget-header, .small-header .widget-header'], Fitness_Sanitize::margin( fitness_get_settings( 'mts_header_adcode_margin' ) ) );

	// Ad-Blocker.
	$css['global']['.navigation-banner']['background'] = Fitness_Sanitize::color( fitness_get_settings( 'navigation_ad_background' ) );
}

/**
 * Social Share Styling
 *
 * @param array $css Array of dynamic CSS.
 */
function fitness_single_social_buttons( &$css ) {

	$social_shadow = fitness_get_settings( 'social_styling_box_shadow' );

	// Social share.
	$css['global']['.shareit-floating'] = Fitness_Sanitize::background( fitness_get_settings( 'social_styling_background' ) );

	// Social share border.
	$social_border = Fitness_Sanitize::border( fitness_get_settings( 'social_styling_border' ) );
	$css['global']['.shareit-floating'][ $social_border ['direction'] ] = $social_border ['value'];

	if ( 0 === $social_shadow ) {
		$css['global']['.shareit-floating']['-webkit-box-shadow'] = 'none';
		$css['global']['.shareit-floating']['box-shadow']         = 'none';
	}
	fitness_merge_value( $css['global']['.shareit-floating'], Fitness_Sanitize::padding( fitness_get_settings( 'social_styling_padding' ) ) );
}

/**
 * Sidebar styling
 *
 * @param array $css Array of dynamic CSS.
 */
function fitness_sidebar_styling( &$css ) {

	// Sidebar.
	fitness_merge_value( $css['global']['#sidebar .widget'], Fitness_Sanitize::background( fitness_get_settings( 'mts_sidebar_styling_background' ) ) );
	fitness_merge_value( $css['global']['#sidebar .widget'], Fitness_Sanitize::margin( fitness_get_settings( 'mts_sidebar_styling_margin' ) ) );
	fitness_merge_value( $css['global']['#sidebar .widget'], Fitness_Sanitize::padding( fitness_get_settings( 'mts_sidebar_styling_padding' ) ) );
	// Sidebar border.
	$sidebar_border = Fitness_Sanitize::border( fitness_get_settings( 'sidebar_styling_border' ) );
	$css['global']['#sidebar .widget'][ $sidebar_border['direction'] ] = $sidebar_border['value'];

	// Sidebar title.
	$sidebar_title                   = '#sidebar .widget h3, #sidebar .widget #wp-subscribe .title';
	$css['global'][ $sidebar_title ] = Fitness_Sanitize::background( fitness_get_settings( 'mts_sidebar_title_styling_background' ) );
	fitness_merge_value( $css['global'][ $sidebar_title ], Fitness_Sanitize::padding( fitness_get_settings( 'mts_sidebar_title_styling_padding' ) ) );
	fitness_merge_value( $css['global'][ $sidebar_title ], Fitness_Sanitize::margin( fitness_get_settings( 'mts_sidebar_title_styling_margin' ) ) );
	// Sidebar Title border.
	$sidebar_title_border = Fitness_Sanitize::border( fitness_get_settings( 'widget_title_border' ) );
	$css['global'][ $sidebar_title ][ $sidebar_title_border['direction'] ] = $sidebar_title_border['value'];
}

/**
 * HomePage sections CSS
 *
 * @param array $css Array of dynamic CSS.
 */
function fitness_home_sections( &$css ) {

	/**
	 * Slider Section.
	 */
	$slider = fitness_get_settings( 'home_slider' );
	$i      = 0;
	if ( ! empty( $slider ) && is_array( $slider ) ) {
		foreach ( $slider as $slide ) {

			++$i;
			$css['global'][ '.slider-item.item-' . $i ]['background-image'] = 'url(' . $slide['slider_background'] . ')';

			$css['global'][ '.slider-item.item-' . $i . ' .slider-overlay' ]['background'] = Fitness_Sanitize::color( $slide['slider_overlay'] );
			$css['global'][ '.slider-item.item-' . $i . ' .slider-title' ]['color']        = Fitness_Sanitize::color( $slide['slider_title_color'] );
			$css['global'][ '.slider-item.item-' . $i . ' .slider-text' ]['color']         = Fitness_Sanitize::color( $slide['slider_desc_color'] );
			$css['global'][ '.slider-item.item-' . $i . ' .button' ]['color']              = Fitness_Sanitize::color( $slide['slider_button_text_color'] );
			$css['global'][ '.slider-item.item-' . $i . ' .button' ]['background-color']   = Fitness_Sanitize::color( $slide['slider_button_bg_color'] );

		}
	}

	//$css['global']['.slider-item']['min-height']            = Fitness_Sanitize::size( fitness_get_settings( 'slider_height' ) . 'px' );
	$css['global']['.slider-item .container']['min-height'] = Fitness_Sanitize::size( fitness_get_settings( 'slider_height' ) . 'px' );
	//fitness_merge_value( $css['global']['.slider-item .container'], Fitness_Sanitize::padding( fitness_get_settings( 'slider_padding' ) ) );
	$top_border_radius = Fitness_Sanitize::margin( fitness_get_settings( 'slider_padding' ) );
	//Top, Right, Bottom, Left Position
	$css['global']['.slider-section .slider-caption']['top']    = $top_border_radius['margin-top'];
	$css['global']['.slider-section .slider-caption']['right']  = $top_border_radius['margin-right'];
	$css['global']['.slider-section .slider-caption']['bottom'] = $top_border_radius['margin-bottom'];
	$css['global']['.slider-section .slider-caption']['left']   = $top_border_radius['margin-left'];

	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'slider_title_font' ) ) );
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'slider_text_font' ) ) );

	/**
	 * Three Column Section.
	 */
	$threegrid = fitness_get_settings( 'home_threegrid' );
	$i         = 0;
	if ( ! empty( $threegrid ) && is_array( $threegrid ) ) {
		foreach ( $threegrid as $grid ) {
			++$i;
			$css['global'][ '.grid-item.item-' . $i ]['background-color']                     = Fitness_Sanitize::color( $grid['threegrid_bg_color'] );
			$css['global'][ '.grid-item.item-' . $i ]['color']                                = Fitness_Sanitize::color( $grid['threegrid_icon_color'] );
			$css['global'][ '.grid-item.item-' . $i . ':hover .overlay' ]['background-color'] = Fitness_Sanitize::color( $grid['threegrid_icon_color'] );
		}
	}
	fitness_merge_value( $css['global']['.threegrid-section'], Fitness_Sanitize::background( fitness_get_settings( 'threegrid_background' ) ) );
	fitness_merge_value( $css['global']['.threegrid-section'], Fitness_Sanitize::padding( fitness_get_settings( 'threegrid_padding' ) ) );
	fitness_merge_value( $css['global']['.threegrid-section'], Fitness_Sanitize::margin( fitness_get_settings( 'threegrid_margin' ) ) );

	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'threegrid_text_font' ) ) );
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'threegrid_title_font' ) ) );

	/**
	 * Two Column Section.
	 */
	fitness_merge_value( $css['global']['.twocolumn-left'], Fitness_Sanitize::background( fitness_get_settings( 'twocolumn_left_image' ) ) );
	fitness_merge_value( $css['global']['.twocolumn-right'], Fitness_Sanitize::background( fitness_get_settings( 'twocolumn_right_image' ) ) );
	$css['global']['.twocolumn-left .cta-overlay']['background-color']  = Fitness_Sanitize::color( fitness_get_settings( 'twocolumn_left_overlay' ) );
	$css['global']['.twocolumn-right .cta-overlay']['background-color'] = Fitness_Sanitize::color( fitness_get_settings( 'twocolumn_right_overlay' ) );
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'twocolumn_heading_font' ) ) );
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'twocolumn_subheading_font' ) ) );
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'twocolumn_title_font' ) ) );
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'twocolumn_button_font' ) ) );
	$css['global']['.twogrid-section .button']['background-color']     = Fitness_Sanitize::color( fitness_get_settings( 'twocolumn_button_bg' ) );
	$css['global']['.two-column-cta-button-inner']['background-color'] = Fitness_Sanitize::color( fitness_get_settings( 'twocolumn_button_back_bg' ) );
	fitness_merge_value( $css['global']['.twogrid-section'], Fitness_Sanitize::margin( fitness_get_settings( 'twocolumn_margin' ) ) );

	/**
	 * Services Section.
	 */
	fitness_merge_value( $css['global']['.services-section'], Fitness_Sanitize::background( fitness_get_settings( 'services_background' ) ) );
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'services_heading_font' ) ) );
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'services_subheading_font' ) ) );
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'services_title_font' ) ) );
	fitness_merge_value( $css['global']['.services-section'], Fitness_Sanitize::padding( fitness_get_settings( 'services_padding' ) ) );
	fitness_merge_value( $css['global']['.services-section'], Fitness_Sanitize::margin( fitness_get_settings( 'services_margin' ) ) );

	/**
	 * Teams Section.
	 */
	fitness_merge_value( $css['global']['.teams-section'], Fitness_Sanitize::background( fitness_get_settings( 'teams_background' ) ) );
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'teams_heading_font' ) ) );
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'teams_subheading_font' ) ) );
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'teams_name_font' ) ) );
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'teams_profession_font' ) ) );
	fitness_merge_value( $css['global']['.teams-section'], Fitness_Sanitize::padding( fitness_get_settings( 'teams_padding' ) ) );
	fitness_merge_value( $css['global']['.teams-section'], Fitness_Sanitize::margin( fitness_get_settings( 'teams_margin' ) ) );
	$css['global']['.team-item img']['border-radius'] = Fitness_Sanitize::size( fitness_get_settings( 'teams_border_radius' ) . 'px' );

	/**
	 * Homepage Blogs Section.
	 */
	fitness_merge_value( $css['global']['.blog-section'], Fitness_Sanitize::background( fitness_get_settings( 'blog_section_background' ) ) );
	$css['global']['.blog-section .blog-overlay']['background-color'] = Fitness_Sanitize::color( fitness_get_settings( 'blog_section_overlay' ) );
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'blog_heading_font' ) ) );
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'blog_subheading_font' ) ) );
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'blog_title_font' ) ) );
	fitness_merge_value( $css['global']['.blog-section'], Fitness_Sanitize::padding( fitness_get_settings( 'blog_section_padding' ) ) );
	fitness_merge_value( $css['global']['.blog-section'], Fitness_Sanitize::margin( fitness_get_settings( 'blog_section_margin' ) ) );

	/**
	 * Clients Section.
	 */
	fitness_merge_value( $css['global']['.clients-section'], Fitness_Sanitize::background( fitness_get_settings( 'clients_background' ) ) );
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'clients_heading_font' ) ) );
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'clients_subheading_font' ) ) );
	fitness_merge_value( $css['global']['.clients-section'], Fitness_Sanitize::padding( fitness_get_settings( 'clients_padding' ) ) );
	fitness_merge_value( $css['global']['.clients-section'], Fitness_Sanitize::margin( fitness_get_settings( 'clients_margin' ) ) );
	// Archive Pages Post date
	$image_elements = array(
		'.archive-posts.layout-default .latestPost-image',
		'.archive [class^="more-page"] .latestPost-image',
		'.search [class^="more-page"] .latestPost-image',
	);
	//border
	$elements = array(
		'.archive-posts.layout-default .latestPost:after',
		'.archive [class^="more-page"] .latestPost:after',
		'.search [class^="more-page"] .latestPost:after',
	);
	if ( fitness_get_settings( 'archive_post_date' ) ) {
		$width = (float) ( 100 / 840 ) * 100;
		$css['global'][ fitness_implode( $image_elements ) ]['margin-left'] = $width . '%';
		$css['global'][ fitness_implode( $elements ) ]['width']             = $width . '%';
	} else {
		$width = (float) ( 370 / 840 ) * 100;
		$css['global'][ fitness_implode( $image_elements ) ]['width'] = $width . '%';
		$css['global'][ fitness_implode( $elements ) ]['width']       = $width . '%';
	}
}

/**
 * Layout CSS
 *
 * @param array $css Array of dynamic CSS.
 */
function fitness_post_layouts( &$css ) {

	// Post Layouts.
	$features = fitness_get_settings( 'mts_featured_categories' );
	foreach ( $features as $feature ) :

		if ( ! isset( $feature['unique_id'] ) ) {
			continue;
		}

		$category     = $feature['mts_featured_category'];
		$posts_layout = isset( $feature['blog_layout'] ) ? $feature['blog_layout'] : 'layout-default';
		$unique_id    = $feature['unique_id'];

		if ( 'layout-default' === $posts_layout ) :
			$posts_layout = 'default';
		endif;

		// Container Class.
		if ( ! in_array( $posts_layout, array( 'default' ) ) ) :
			$container_class = array(
				'.layout-' . $unique_id,
			);
			$css['global'][ fitness_implode( $container_class ) ] = array(
				'width'    => '100%',
				'float'    => 'none',
				'overflow' => 'visible',
				'position' => 'relative',
			);
		endif;
		if ( ! in_array( $posts_layout, array( 'default' ) ) ) :
			$all_class                                      = array(
				'.layout-' . $unique_id . ' .latestPost .title',
			);
			$css['global'][ fitness_implode( $all_class ) ] = array(
				'line-height' => '1',
				'font-size'   => 'inherit',
			);
		endif;

		// Section title align.
		$post_title_align = fitness_get_settings( 'mts_post_title_alignment_' . $unique_id );

		// Post area.
		$cat_class = 'cat-latest';
		if ( 'latest' !== $category ) {
			$category  = get_term_by( 'slug', $category, 'category' );
			$cat_class = sanitize_key( $category->name );
		}

		$title_class = '.title-container.title-id-' . $unique_id . ' h3';

		$css['global'][ $title_class ] = Fitness_Sanitize::background( fitness_get_settings( 'mts_featured_category_title_background_' . $unique_id ) );
		fitness_merge_value( $css['global'][ $title_class ], Fitness_Sanitize::margin( fitness_get_settings( 'mts_featured_category_title_margin_' . $unique_id ) ) );
		fitness_merge_value( $css['global'][ $title_class ], Fitness_Sanitize::padding( fitness_get_settings( 'mts_featured_category_title_padding_' . $unique_id ) ) );
		// Section title border.
		$post_title_border = Fitness_Sanitize::border( fitness_get_settings( 'post_title_border_' . $unique_id ) );
		$css['global'][ $title_class ][ $post_title_border['direction'] ] = $post_title_border['value'];

		// Title alignment.
		$align_class = '.title-container.title-id-' . $unique_id;
		if ( 'center' === $post_title_align ) :
			$css['global'][ $align_class ]['text-align'] = 'center';
		elseif ( 'right' === $post_title_align ) :
			$css['global'][ $align_class ]['text-align']              = 'right';
			$css['global'][ $align_class . ' + .view-more' ]['left']  = '0';
			$css['global'][ $align_class . ' + .view-more' ]['right'] = 'auto';
		endif;

		fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'mts_featured_category_title_font_' . $unique_id ) ) );

		if ( 'layout-featured' !== $posts_layout ) {
			$post_class = '.layout-' . $unique_id . '.default-container';
		} else {
			$post_class = '.layout-' . $unique_id;
		}

		// Post border.
		$post_border = Fitness_Sanitize::border( fitness_get_settings( 'post_border_' . $unique_id ) );
		$css['global'][ $post_class ][ $post_border['direction'] ] = $post_border['value'];

		fitness_merge_value( $css['global'][ $post_class ], Fitness_Sanitize::margin( fitness_get_settings( 'post_margin_' . $unique_id ) ) );
		fitness_merge_value( $css['global'][ $post_class ], Fitness_Sanitize::padding( fitness_get_settings( 'post_padding_' . $unique_id ) ) );

		/**
		 * Meta info
		 */

		fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'meta_info_font_' . $unique_id ) ) );

		fitness_merge_value( $css['global'][ '.layout-' . $unique_id . ' .latestPost .post-info' ], Fitness_Sanitize::margin( fitness_get_settings( 'mts_meta_info_margin_' . $unique_id ) ) );

		fitness_merge_value( $css['global'][ '.layout-' . $unique_id . ' .latestPost .post-info' ], Fitness_Sanitize::padding( fitness_get_settings( 'mts_meta_info_padding_' . $unique_id ) ) );

		$css['global'][ '.layout-' . $unique_id . ' .post-info > span' ]['background-color'] = Fitness_Sanitize::color( fitness_get_settings( 'home_meta_info_bg_' . $unique_id ) );

		fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'post_title_font_' . $unique_id ) ) );

		//if ( 'layout-featured' !== $posts_layout ) {
		fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'post_excerpt_font_' . $unique_id ) ) );
		fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'post_date_font_' . $unique_id ) ) );

		if ( fitness_get_settings( 'post_date_' . $unique_id ) ) {
			$width = (float) ( 100 / 840 ) * 100;
			$css['global'][ '.layout-' . $unique_id . ' .latestPost-image' ]['margin-left'] = $width . '%';
			$css['global'][ '.layout-' . $unique_id . ' .latestPost:after' ]['width']       = $width . '%';
		} else {
			$width = (float) ( 370 / 840 ) * 100;
			$css['global'][ '.layout-' . $unique_id . ' .layout-default .latestPost .latestPost-image' ]['width'] = $width . '%';
			$css['global'][ '.layout-' . $unique_id . ' .layout-default .latestPost .latestPost:after' ]['width'] = $width . '%';
		}

		// Border.
		$meta_info_border = Fitness_Sanitize::border( fitness_get_settings( 'meta_info_border_' . $unique_id ) );
		$css['global'][ '.layout-' . $unique_id . ' .layout-default .latestPost .post-info' ][ $meta_info_border['direction'] ] = $meta_info_border['value'];

	endforeach;
}

/**
 * Pagination
 *
 * @param array $css Array of dynamic CSS.
 */
function fitness_post_pagination( &$css ) {

	// Pagination Active class.
	$pagination_class_active = array(
		'.pace .pace-progress',
		'.page-numbers.current',
		'.pagination a:hover',
		'#mobile-menu-wrapper ul li a:hover',
		'#load-posts a:hover',
	);
	$pagination_class        = array(
		'.pagination a',
		'#load-posts a',
		'.single .pagination > .current > .currenttext',
		'.pagination .page-numbers.dots',
	);
	fitness_merge_value( $css['global'][ fitness_implode( array_merge( $pagination_class_active, $pagination_class ) ) ], Fitness_Sanitize::margin( fitness_get_settings( 'mts_pagenavigation_margin' ) ) );
	if ( '2' !== fitness_get_settings( 'mts_pagenavigation_type' ) ) {
		$css['global'][ fitness_implode( $pagination_class ) ]['background-color'] = Fitness_Sanitize::color( fitness_get_settings( 'mts_pagenavigation_bgcolor' ) );

		$css['global'][ fitness_implode( $pagination_class_active ) ]['background-color'] = Fitness_Sanitize::color( fitness_get_settings( 'mts_pagenavigation_hover_bgcolor' ) );

		$css['global'][ fitness_implode( $pagination_class ) ]['color'] = Fitness_Sanitize::color( fitness_get_settings( 'mts_pagenavigation_color' ) );

		$css['global'][ fitness_implode( $pagination_class_active ) ]['color'] = Fitness_Sanitize::color( fitness_get_settings( 'mts_pagenavigation_hover_color' ) );

		$css['global']['.pagination .page-numbers i']['color']       = Fitness_Sanitize::color( fitness_get_settings( 'mts_pagenavigation_hover_bgcolor' ) );
		$css['global']['.pagination-previous-next i']['color']       = Fitness_Sanitize::color( fitness_get_settings( 'mts_pagenavigation_hover_bgcolor' ) );
		$css['global']['.pagination .page-numbers:hover i']['color'] = Fitness_Sanitize::color( fitness_get_settings( 'mts_pagenavigation_hover_color' ) );
		//Next Prev hover color
		$css['global']['.pagination-previous-next a:hover i']['color'] = Fitness_Sanitize::color( fitness_get_settings( 'mts_pagenavigation_hover_color' ) );

		fitness_merge_value( $css['global'][ fitness_implode( array_merge( $pagination_class_active, $pagination_class ) ) ], Fitness_Sanitize::padding( fitness_get_settings( 'mts_pagenavigation_padding' ) ) );
	} else {
		$css['global'][ fitness_implode( $pagination_class ) ]['background-color'] = Fitness_Sanitize::color( fitness_get_settings( 'load_more_bgcolor' ) );

		$css['global'][ fitness_implode( $pagination_class_active ) ]['background-color'] = Fitness_Sanitize::color( fitness_get_settings( 'load_more_hover_bgcolor' ) );

		$css['global'][ fitness_implode( $pagination_class ) ]['color'] = Fitness_Sanitize::color( fitness_get_settings( 'load_more_color' ) );

		$css['global'][ fitness_implode( $pagination_class_active ) ]['color'] = Fitness_Sanitize::color( fitness_get_settings( 'load_more_hover_color' ) );

		fitness_merge_value( $css['global']['#load-posts a'], Fitness_Sanitize::padding( fitness_get_settings( 'load_more_padding' ) ) );
	}
	$css['global'][ fitness_implode( $pagination_class ) ]['border-radius']        = Fitness_Sanitize::size( fitness_get_settings( 'mts_pagenavigation_border_radius' ) . 'px' );
	$css['global'][ fitness_implode( $pagination_class_active ) ]['border-radius'] = Fitness_Sanitize::size( fitness_get_settings( 'mts_pagenavigation_border_radius' ) . 'px' );

	// Pagination border.
	$pagination_border = Fitness_Sanitize::border( fitness_get_settings( 'pagenavigation_border' ) );
	$css['global'][ fitness_implode( $pagination_class ) ][ $pagination_border ['direction'] ] = $pagination_border ['value'];

	// Pagination Alignment.
	$pagenavigation_align = fitness_get_settings( 'pagenavigation_alignment' );
	if ( 'left' === $pagenavigation_align ) :
		$css['global']['.pagination']['text-align'] = 'left';
	elseif ( 'right' === $pagenavigation_align ) :
		$css['global']['.pagination']['text-align'] = 'right';
	endif;

	// Load more Alignment.
	$load_more_align = fitness_get_settings( 'load_more_alignment' );
	if ( 'left' === $load_more_align ) :
		$css['global']['#load-posts']['text-align'] = 'left';
	elseif ( 'right' === $load_more_align ) :
		$css['global']['#load-posts']['text-align'] = 'right';
	elseif ( 'full' === $load_more_align ) :
		$css['global']['#load-posts a']['width'] = '100%';
	endif;
}

/**
 * Single
 *
 * @param array $css Array of dynamic CSS.
 */
function fitness_single( &$css ) {

	// Single, Page, Archive, Search, Category and 404 Page Background.
	$page_classes = array(
		'.single .article',
		'.page .article',
		'.search .article',
		'.archive .article',
		'.error404 .article',
	);

	$css['global'][ fitness_implode( $page_classes ) ] = Fitness_Sanitize::background( fitness_get_settings( 'single_background' ) );

	// Margin, Padding, Border and Box Shadow.
	fitness_merge_value( $css['global'][ fitness_implode( $page_classes ) ], Fitness_Sanitize::margin( fitness_get_settings( 'mts_single_styling_margin' ) ) );
	fitness_merge_value( $css['global'][ fitness_implode( $page_classes ) ], Fitness_Sanitize::padding( fitness_get_settings( 'mts_single_styling_padding' ) ) );

	// Single border.
	$single_border = Fitness_Sanitize::border( fitness_get_settings( 'single_styling_border' ) );
	$css['global']['.article'][ $single_border ['direction'] ] = $single_border ['value'];

	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'mts_single_meta_info_font' ) ) );
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'single_category_post_font' ) ) );

	// Tags.
	$css['global']['.tags a, .tagcloud a, .widget .wpt_widget_content #tags-tab-content ul li a']['background-color'] = Fitness_Sanitize::color( fitness_get_settings( 'tags_bgcolor' ) );

	// Related Posts.
	$css['global']['.related-posts'] = Fitness_Sanitize::background( fitness_get_settings( 'related_posts_background' ) );
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'related_posts_font' ) ) );
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'related_posts_meta_font' ) ) );
	fitness_map_css_selectors( $css['global'], Fitness_Sanitize::typography( fitness_get_settings( 'related_posts_excerpt' ) ) );
	fitness_merge_value( $css['global']['.related-posts'], Fitness_Sanitize::margin( fitness_get_settings( 'related_posts_margin' ) ) );
	fitness_merge_value( $css['global']['.related-posts'], Fitness_Sanitize::padding( fitness_get_settings( 'related_posts_padding' ) ) );
		$css['global']['.related-posts .post-info > span']['background-color'] = Fitness_Sanitize::color( fitness_get_settings( 'related_post_meta_bg' ) );

	$related_posts_border = Fitness_Sanitize::border( fitness_get_settings( 'related_posts_border' ) );
	$css['global']['.related-posts'][ $related_posts_border ['direction'] ] = $related_posts_border ['value'];

	// Related Posts articles.
	$css['global']['.related-posts article'] = Fitness_Sanitize::background( fitness_get_settings( 'related_article_background' ) );
	fitness_merge_value( $css['global']['.related-posts article'], Fitness_Sanitize::padding( fitness_get_settings( 'related_article_padding' ) ) );
	fitness_merge_value( $css['global']['.related-posts article header'], Fitness_Sanitize::padding( fitness_get_settings( 'related_article_text_padding' ) ) );

	// Meta info Background.
	$css['global']['.single-header .post-info > span']['background-color'] = Fitness_Sanitize::color( fitness_get_settings( 'single_meta_info_background' ) );
	$css['global']['body .thesinglecategory a']['background-color']        = Fitness_Sanitize::color( fitness_get_settings( 'single_category_post_background' ) );

	// Subscribe Box.
	$css['global']['.single-subscribe .widget #wp-subscribe'] = Fitness_Sanitize::background( fitness_get_settings( 'single_subscribe_background' ) );
	fitness_merge_value( $css['global']['.single-subscribe .widget #wp-subscribe'], Fitness_Sanitize::margin( fitness_get_settings( 'single_subscribe_margin' ) ) );
	fitness_merge_value( $css['global']['.single-subscribe .widget #wp-subscribe'], Fitness_Sanitize::padding( fitness_get_settings( 'single_subscribe_padding' ) ) );
	$css['global']['.single-subscribe .widget #wp-subscribe']['border-radius'] = Fitness_Sanitize::size( fitness_get_settings( 'single_subscribe_border_radius' ) . 'px' );

	// Subscribe Box Input fields.
	$subscribe_input_class = array(
		'.single-subscribe #wp-subscribe input.email-field',
		'.single-subscribe #wp-subscribe input.name-field',
	);
	$css['global'][ fitness_implode( $subscribe_input_class ) ]['background-color'] = Fitness_Sanitize::color( fitness_get_settings( 'single_subscribe_input_background' ) );

	$css['global'][ fitness_implode( $subscribe_input_class ) ]['height'] = Fitness_Sanitize::size( fitness_get_settings( 'single_subscribe_input_height' ) . 'px' );

	$css['global']['.single-subscribe .widget #wp-subscribe input.submit']['height'] = Fitness_Sanitize::size( fitness_get_settings( 'single_subscribe_input_height' ) . 'px' );

	$css['global'][ fitness_implode( $subscribe_input_class ) ]['border-radius'] = Fitness_Sanitize::size( fitness_get_settings( 'single_subscribe_input_border_radius' ) . 'px' );

	// Subscribe Box Input border.
	$subscribe_box_input_border = Fitness_Sanitize::border( fitness_get_settings( 'single_subscribe_input_border' ) );
	$css['global'][ fitness_implode( $subscribe_input_class ) ][ $subscribe_box_input_border ['direction'] ] = $subscribe_box_input_border ['value'];

	// Subscribe Box Submit button.
	$css['global']['.single-subscribe .widget #wp-subscribe input.submit']['background']    = Fitness_Sanitize::color( fitness_get_settings( 'single_subscribe_submit_backgroud' ) );
	$css['global']['.single-subscribe .widget #wp-subscribe input.submit']['border-radius'] = Fitness_Sanitize::size( fitness_get_settings( 'single_subscribe_submit_border_radius' ) . 'px' );

	// Subscribe Box Submit border.
	$subscribe_box_submit_border = Fitness_Sanitize::border( fitness_get_settings( 'single_subscribe_submit_border' ) );
	$css['global']['.single-subscribe .widget #wp-subscribe input.submit'][ $subscribe_box_submit_border ['direction'] ] = $subscribe_box_submit_border ['value'];

	fitness_merge_value( $css['global']['.single-subscribe .widget #wp-subscribe input.submit'], Fitness_Sanitize::padding( fitness_get_settings( 'single_subscribe_submit_padding' ) ) );

	// Author Box.
	$css['global']['.postauthor'] = Fitness_Sanitize::background( fitness_get_settings( 'single_authorbox_background' ) );
	fitness_merge_value( $css['global']['.postauthor'], Fitness_Sanitize::margin( fitness_get_settings( 'single_authorbox_margin' ) ) );
	fitness_merge_value( $css['global']['.postauthor'], Fitness_Sanitize::padding( fitness_get_settings( 'single_authorbox_padding' ) ) );
	$css['global']['.postauthor']['border-radius'] = Fitness_Sanitize::size( fitness_get_settings( 'single_authorbox_border_radius' ) . 'px' );
	$single_authorbox_border                       = Fitness_Sanitize::border( fitness_get_settings( 'single_authorbox_border' ) );
	$css['global']['.postauthor'][ $single_authorbox_border ['direction'] ] = $single_authorbox_border ['value'];
	// Author image.
	fitness_merge_value( $css['global']['.postauthor img'], Fitness_Sanitize::margin( fitness_get_settings( 'single_author_image_margin' ) ) );
	$css['global']['.postauthor img']['border-radius'] = Fitness_Sanitize::size( fitness_get_settings( 'single_author_image_border_radius' ) . 'px' );
	// Author Social
	fitness_merge_value( $css['global']['.author-social a'], Fitness_Sanitize::margin( fitness_get_settings( 'author_social_margin' ) ) );
	//fitness_merge_value( $css['global']['.author-social a'], Fitness_Sanitize::padding( fitness_get_settings( 'author_social_padding' ) ) );
	$css['global']['.author-social a']['min-width']     = Fitness_Sanitize::size( fitness_get_settings( 'author_social_width' ) . 'px' );
	$css['global']['.author-social a']['height']        = Fitness_Sanitize::size( fitness_get_settings( 'author_social_height' ) . 'px' );
	$css['global']['.author-social a']['line-height']   = Fitness_Sanitize::size( fitness_get_settings( 'author_social_height' ) . 'px' );
	$css['global']['.author-social a']['border-radius'] = Fitness_Sanitize::size( fitness_get_settings( 'author_social_border_radius' ) . 'px' );

	$single_author_image_margin = Fitness_Sanitize::margin( fitness_get_settings( 'single_author_image_margin' ) );
	//Top, Right, Bottom, Left Position
	$css['global']['.author-social']['padding-left'] = (int) $single_author_image_margin['margin-right'] + '100' . 'px';

	// Single Page titles Styling.
	$titles_align = fitness_get_settings( 'single_title_alignment' );

	$titles_align_class = array(
		'.comment-title',
		'#respond',
		'.related-posts-title',
	);
	$titles_class       = array(
		'#respond h3',
		'#respond h4',
		'.total-comments',
		'.related-posts h4',
	);

	$css['global'][ fitness_implode( $titles_class ) ] = Fitness_Sanitize::background( fitness_get_settings( 'single_title_background' ) );
	fitness_merge_value( $css['global'][ fitness_implode( $titles_class ) ], Fitness_Sanitize::padding( fitness_get_settings( 'single_title_padding' ) ) );
	// Single title border.
	$single_titles_border = Fitness_Sanitize::border( fitness_get_settings( 'single_title_border' ) );
	$css['global'][ fitness_implode( $titles_class ) ][ $single_titles_border ['direction'] ] = $single_titles_border ['value'];

	if ( 'left' === $titles_align ) :
		$css['global'][ fitness_implode( $titles_class ) ]['display'] = 'inline-block';
	elseif ( 'center' === $titles_align ) :
		$css['global'][ fitness_implode( $titles_align_class ) ]['text-align'] = 'center';
		$css['global'][ fitness_implode( $titles_class ) ]['display']          = 'inline-block';
	elseif ( 'right' === $titles_align ) :
		$css['global'][ fitness_implode( $titles_align_class ) ]['text-align'] = 'right';
		$css['global'][ fitness_implode( $titles_class ) ]['display']          = 'inline-block';
	endif;
	//Breadcrumbs section
	$css['global']['.breadcrumbs-section'] = Fitness_Sanitize::background( fitness_get_settings( 'breadcrumb_background' ) );
	//Breadcrumbs Margin Padding
	fitness_merge_value( $css['global']['.breadcrumbs-section'], Fitness_Sanitize::margin( fitness_get_settings( 'breadcrumb_margin' ) ) );
	fitness_merge_value( $css['global']['.breadcrumbs-section'], Fitness_Sanitize::padding( fitness_get_settings( 'breadcrumb_padding' ) ) );
	//border
	$breadcrumb_border = Fitness_Sanitize::border( fitness_get_settings( 'breadcrumb_border' ) );
	$css['global']['.breadcrumbs-section'][ $breadcrumb_border ['direction'] ] = $breadcrumb_border ['value'];
	if ( empty( fitness_get_settings( 'mts_blog_title' ) ) || empty( fitness_get_settings( 'single_heading_text' ) ) ) {
		$breadcrumb_class = array(
			'.breadcrumbs-section .container .breadcrumb',
			'.breadcrumbs-section .container .rank-math-breadcrumb',
		);
		$css['global'][ fitness_implode( $breadcrumb_class ) ]['-webkit-box-pack'] = 'inherit';
		$css['global'][ fitness_implode( $breadcrumb_class ) ]['-ms-flex-pack']    = 'inherit';
		$css['global'][ fitness_implode( $breadcrumb_class ) ]['justify-content']  = 'inherit';
	}
}

/**
 * Copyrights
 *
 * @param array $css Array of dynamic CSS.
 */
function fitness_copyrights( &$css ) {

	// copyrights border.
	$copyrights_border = Fitness_Sanitize::border( fitness_get_settings( 'copyrights_border' ) );
	$css['global']['.copyrights .container'][ $copyrights_border ['direction'] ] = $copyrights_border ['value'];

}

/**
 * Footer
 *
 * @param array $css Array of dynamic CSS.
 */
function fitness_footer( &$css ) {

	// Footer.
	fitness_merge_value( $css['global']['#site-footer'], Fitness_Sanitize::margin( fitness_get_settings( 'mts_top_footer_margin' ) ) );
	fitness_merge_value( $css['global']['#site-footer'], Fitness_Sanitize::padding( fitness_get_settings( 'mts_top_footer_padding' ) ) );

	// Footer widgets.
	if ( 1 === fitness_get_settings( 'mts_top_footer' ) && 1 === fitness_get_settings( 'mts_top_footer_num' ) ) :
		$css['global']['.footer-widgets']['display']                = 'flex';
		$css['global']['.footer-widgets']['justify-content']        = 'center';
		$css['global']['.footer-widgets .f-widget']['width']        = '38.7387388%';
		$css['global']['.footer-widgets .f-widget']['text-align']   = 'center';
		$css['global']['.footer-widgets .f-widget']['margin-right'] = '0px';
	endif;

	// Footer Navigation Section.
	fitness_merge_value( $css['global']['.footer-nav-section'], Fitness_Sanitize::margin( fitness_get_settings( 'footer_nav_margin' ) ) );
	fitness_merge_value( $css['global']['.footer-nav-section'], Fitness_Sanitize::padding( fitness_get_settings( 'footer_nav_padding' ) ) );

	// footer Nav border.
	$footer_nav_border = Fitness_Sanitize::border( fitness_get_settings( 'footer_nav_border' ) );
	$css['global']['.footer-nav-section'][ $footer_nav_border ['direction'] ] = $footer_nav_border ['value'];

	// footer Nav position.
	$footer_sections_position = fitness_get_settings( 'footer_sections_position' );
	if ( 1 === fitness_get_settings( 'footer_nav_section' ) || 1 === fitness_get_settings( 'footer_brands_section' ) ) :
		if ( 'left' === $footer_sections_position || 'right' === $footer_sections_position ) :
			$css['global']['#site-footer .container']['display']   = 'flex';
			$css['global']['#site-footer .container']['flex-flow'] = 'row wrap';
			$css['global']['.footer-sections']['flex-basis']       = 'calc(25% - 20px )';
			$css['global']['.footer-sections']['padding-right']    = '20px';
			$css['global']['.footer-widgets']['flex-basis']        = '75%';
			$css['global']['.brands-container']['display']         = 'block';
			$css['global']['.brands-items li']['max-width']        = '100%';
			$css['global']['.brands-items li']['flex-basis']       = '60%';
		endif;
		if ( 'right' === $footer_sections_position ) :
			$css['global']['#site-footer .container']['flex-direction'] = 'row-reverse';
			$css['global']['.footer-sections']['padding-right']         = '0';
			$css['global']['.footer-sections']['padding-left']          = '20px';
			$css['global']['.brands-container']['text-align']           = 'right';
			$css['global']['.brands-items']['justify-content']          = 'flex-end';
		endif;
	endif;

	// footer Nav alignment.
	$footer_nav_align = fitness_get_settings( 'footer_nav_alignment' );
	if ( 'left' === $footer_nav_align ) :
		$css['global']['.footer-nav-section']['text-align'] = 'left';
	elseif ( 'center' === $footer_nav_align ) :
		$css['global']['.footer-nav-section']['text-align'] = 'center';
	elseif ( 'right' === $footer_nav_align ) :
		$css['global']['.footer-nav-section']['text-align'] = 'right';
	endif;

	// footer Nav menu item.
	fitness_merge_value( $css['global']['.footer-nav-container li a'], Fitness_Sanitize::margin( fitness_get_settings( 'footer_menu_item_margin' ) ) );

	// footer Nav separator.
	fitness_merge_value( $css['global']['.footer-nav-container .footer-separator'], Fitness_Sanitize::margin( fitness_get_settings( 'footer_nav_separator_margin' ) ) );
	$css['global']['.footer-nav-container .footer-separator']['color'] = Fitness_Sanitize::color( fitness_get_settings( 'footer_nav_separator_color' ) );

	// Footer Logo Social icons.
	if ( 1 === fitness_get_settings( 'footer_logo_social_icons' ) && ! empty( fitness_get_settings( 'footer_logo_social' ) ) && is_array( fitness_get_settings( 'footer_logo_social' ) ) ) :
		$footer_nav_icons = fitness_get_settings( 'footer_logo_social' );
		foreach ( $footer_nav_icons as $footer_nav_icon ) :
			$footer_icons[]               = $footer_nav_icon['footer_logo_social_icon'];
			$footer_nav_icon_border_size  = $footer_nav_icon['footer_logo_social_border_size'];
			$footer_nav_icon_border_style = $footer_nav_icon['footer_logo_social_border_style'];
			$footer_nav_icon_border_color = $footer_nav_icon['footer_logo_social_border_color'];
			$footer_nav_icon_border       = $footer_nav_icon_border_size . 'px ' . $footer_nav_icon_border_style . ' ' . $footer_nav_icon_border_color;
			$css['global'][ '.footer-logo-social-icons a.footer-logo-' . $footer_nav_icon['footer_logo_social_icon'] ]['background-color']            = Fitness_Sanitize::color( $footer_nav_icon['footer_logo_social_bgcolor'] );
			$css['global'][ '.footer-logo-social-icons a.footer-logo-' . $footer_nav_icon['footer_logo_social_icon'] . ':hover' ]['background-color'] = Fitness_Sanitize::color( $footer_nav_icon['footer_logo_social_hover_bgcolor'] );
			$css['global'][ '.footer-logo-social-icons a.footer-logo-' . $footer_nav_icon['footer_logo_social_icon'] ]['color']                       = Fitness_Sanitize::color( $footer_nav_icon['footer_logo_social_color'] );
			$css['global'][ '.footer-logo-social-icons a.footer-logo-' . $footer_nav_icon['footer_logo_social_icon'] . ':hover' ]['color']            = Fitness_Sanitize::color( $footer_nav_icon['footer_logo_social_hover_color'] );
			fitness_merge_value( $css['global'][ '.footer-logo-social-icons a.footer-logo-' . $footer_nav_icon['footer_logo_social_icon'] ], Fitness_Sanitize::margin( $footer_nav_icon['footer_logo_social_margin'] ) );
			fitness_merge_value( $css['global'][ '.footer-logo-social-icons a.footer-logo-' . $footer_nav_icon['footer_logo_social_icon'] ], Fitness_Sanitize::padding( $footer_nav_icon['footer_logo_social_padding'] ) );
			$css['global'][ '.footer-logo-social-icons a.footer-logo-' . $footer_nav_icon['footer_logo_social_icon'] ]['border-radius'] = Fitness_Sanitize::size( $footer_nav_icon['footer_logo_social_border_radius'] . 'px' );
			$css['global'][ '.footer-logo-social-icons a.footer-logo-' . $footer_nav_icon['footer_logo_social_icon'] ]['border']        = $footer_nav_icon_border;
		endforeach;
	endif;

	// Footer Nav Social icons font size.
	if ( ! empty( $footer_icons ) && is_array( $footer_icons ) ) :
		foreach ( $footer_icons as $footer_icon ) :
			$css['global'][ '.footer-logo-social-icons a.footer-logo-' . $footer_icon ]['font-size'] = Fitness_Sanitize::size( fitness_get_settings( 'footer_logo_social_font_size' ) . 'px' );
		endforeach;
	endif;

	// Footer Brands Sections.
	$brands_border = Fitness_Sanitize::border( fitness_get_settings( 'brands_border' ) );
	$css['global']['.brands-container'][ $brands_border ['direction'] ] = $brands_border ['value'];

	// footer brands alignment.
	$footer_brands_align = fitness_get_settings( 'footer_brands_alignment' );
	if ( 'center' === $footer_brands_align ) :
		$css['global']['.brands-container']['justify-content'] = 'center';
	elseif ( 'right' === $footer_brands_align ) :
		$css['global']['.brands-container']['justify-content'] = 'flex-end';
	endif;

	// brand container.
	fitness_merge_value( $css['global']['.brands-container'], Fitness_Sanitize::margin( fitness_get_settings( 'brands_margin' ) ) );
	fitness_merge_value( $css['global']['.brands-container'], Fitness_Sanitize::padding( fitness_get_settings( 'brands_padding' ) ) );

}

/**
 * Misc
 *
 * @param array $css Array of dynamic CSS.
 */
function fitness_misc_css( &$css ) {

	// Show Logo.
	$show_logo = fitness_get_settings( 'mts_header_section2' );

	if ( 0 === $show_logo ) {
		$css['global']['.logo-wrap']['display'] = 'none';
	}

	// Back to top.
	// Border.
	$top_button_border = Fitness_Sanitize::border( fitness_get_settings( 'top_button_border' ) );
	$css['global']['#move-to-top'][ $top_button_border ['direction'] ] = $top_button_border ['value'];
	// Font-size, Padding and Position.
	$css['global']['#move-to-top .fa']['font-size'] = Fitness_Sanitize::size( fitness_get_settings( 'top_button_font_size' ) . 'px' );
	//Top button position
	$top_button_position = fitness_get_settings( 'top_button_position' );
	foreach ( $top_button_position as $key => $position ) {
		$css['global']['#move-to-top'][ $key ] = $position;
	}
	// Border-radius.
	$css['global']['#move-to-top']['border-radius'] = Fitness_Sanitize::size( fitness_get_settings( 'top_button_border_radius' ) . 'px' );
	// Height Width of back to top
	$css['global']['#move-to-top']['min-width']     = Fitness_Sanitize::size( fitness_get_settings( 'top_button_width' ) . 'px' );
	$css['global']['#move-to-top']['height']        = Fitness_Sanitize::size( fitness_get_settings( 'top_button_height' ) . 'px' );
	$css['global']['#move-to-top i']['line-height'] = Fitness_Sanitize::size( fitness_get_settings( 'top_button_height' ) . 'px' );
	// Colors.
	$css['global']['#move-to-top']['color']            = Fitness_Sanitize::color( fitness_get_settings( 'top_button_color' ) );
	$css['global']['#move-to-top:hover']['color']      = Fitness_Sanitize::color( fitness_get_settings( 'top_button_color_hover' ) );
	$css['global']['#move-to-top']['background']       = Fitness_Sanitize::color( fitness_get_settings( 'top_button_background' ) );
	$css['global']['#move-to-top:hover']['background'] = Fitness_Sanitize::color( fitness_get_settings( 'top_button_background_hover' ) );
}
